'use strict';

var React = require('react');
var jsxRuntime = require('react/jsx-runtime');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var React__default = /*#__PURE__*/_interopDefault(React);

// src/useCodeSpotlight.ts
var useCodeSpotlight = () => {
  const { id, mode, ref } = useCodeSpotlightContext();
  const focusTarget = (target) => {
    const codeBlock = ref?.current;
    if (!codeBlock) return;
    codeBlock.setAttribute("data-hovered", "true");
    const tokens = codeBlock.querySelectorAll("span");
    tokens.forEach((token) => {
      if (mode === "equal" && token.textContent === target) {
        token.classList.add("spotlight-target");
      } else if (mode === "include" && token.textContent?.includes(target)) {
        token.classList.add("spotlight-target");
      } else {
        token.classList.remove("spotlight-target");
      }
    });
  };
  const unfocusTarget = () => {
    const codeBlock = ref?.current;
    if (!codeBlock) return;
    codeBlock.setAttribute("data-hovered", "false");
    const tokens = codeBlock.querySelectorAll("span");
    tokens.forEach((token) => {
      token.classList.remove("spotlight-target");
    });
  };
  return { id, focusTarget, unfocusTarget };
};
var CodeSpotlightContext = React.createContext({
  ref: null,
  id: "",
  mode: "equal"
});
function useCodeSpotlightContext() {
  const context = React.useContext(CodeSpotlightContext);
  if (!context) {
    console.error(
      "[code-spotlight] useCodeSpotlight must be used within a CodeSpotlightProvider"
    );
  }
  return context;
}
function CodeSpotlight({
  children,
  mode = "include"
}) {
  const preRef = React.useRef(null);
  const id = React.useId();
  const value = React.useMemo(() => ({ id, mode, ref: preRef }), [id, mode, preRef]);
  return /* @__PURE__ */ jsxRuntime.jsx(CodeSpotlightContext.Provider, { value, children: React__default.default.Children.map(children, (child) => {
    if (typeof child === "object" && child !== null && "type" in child && child.type === "pre") {
      return React__default.default.cloneElement(child, {
        id,
        className: child.props && typeof child.props === "object" && "className" in child.props ? `${child.props.className} code-spotlight-container` : "code-spotlight-container",
        ref: preRef
      });
    }
    return child;
  }) });
}
function CodeSpotlightTrigger({
  children,
  target
}) {
  const { focusTarget, unfocusTarget } = useCodeSpotlight();
  return /* @__PURE__ */ jsxRuntime.jsx(
    "code",
    {
      className: "code-spotlight-trigger",
      onMouseEnter: () => focusTarget(target),
      onMouseLeave: unfocusTarget,
      children
    }
  );
}
CodeSpotlight.Trigger = CodeSpotlightTrigger;

exports.CodeSpotlight = CodeSpotlight;
exports.CodeSpotlightTrigger = CodeSpotlightTrigger;
exports.useCodeSpotlight = useCodeSpotlight;
